==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebSummaryOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryOperandDescription } from "./WebSummaryOperandDescription";
/**
 * @hidden
 */
export let WebSummaryOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryOperandDescriptionMetadata.a == null) {
                WebSummaryOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryOperandDescriptionMetadata.c(WebSummaryOperandDescriptionMetadata.a);
            }
            if (a.j(WebSummaryOperandDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSummaryOperandDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryOperand");
            a.item("__packageNameWC", "String:grids");
        }
        static d(a) {
            WebSummaryOperandDescriptionMetadata.b(a);
            a.aa("WebSummaryOperand", () => new WebSummaryOperandDescription());
            a.z("WebSummaryOperand", WebSummaryOperandDescriptionMetadata.a);
        }
    }
    WebSummaryOperandDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryOperandDescriptionMetadata, 'WebSummaryOperandDescriptionMetadata');
    WebSummaryOperandDescriptionMetadata.a = null;
    return WebSummaryOperandDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSummaryOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryOperandDescription } from "./WebSummaryOperandDescription";
/**
 * @hidden
 */
export let WebSummaryOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryOperandDescriptionMetadata.a == null) {
                WebSummaryOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryOperandDescriptionMetadata.c(WebSummaryOperandDescriptionMetadata.a);
            }
            if (a.k(WebSummaryOperandDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSummaryOperandDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        }
        static d(a) {
            WebSummaryOperandDescriptionMetadata.b(a);
            a.ac("WebSummaryOperand", () => new WebSummaryOperandDescription());
            a.ab("WebSummaryOperand", WebSummaryOperandDescriptionMetadata.a);
        }
    }
    WebSummaryOperandDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryOperandDescriptionMetadata, 'WebSummaryOperandDescriptionMetadata');
    WebSummaryOperandDescriptionMetadata.a = null;
    return WebSummaryOperandDescriptionMetadata;
})();
